﻿using Syncfusion.SfChart.XForms;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;

namespace LineDragAndDrop
{
    public class SampleChart : ContentPage
    {
        ViewModel dataModel;

        CustomChart chart;

        public SampleChart()
        {
            StackLayout layout = new StackLayout() { Padding = new Thickness(5, 15, 5, 5) };

            dataModel = new ViewModel();

            chart = new CustomChart();
            chart.VerticalOptions = LayoutOptions.FillAndExpand;
            chart.HorizontalOptions = LayoutOptions.FillAndExpand;
            chart.BindingContext = dataModel;

            NumericalAxis datetimeAxis = new NumericalAxis();
            chart.PrimaryAxis = datetimeAxis;

            NumericalAxis numericalAxis = new NumericalAxis();
            chart.SecondaryAxis = numericalAxis;

            chart.Series.Add(new LineSeries()
            {
                DataMarker = new ChartDataMarker
                {
                    ShowMarker = true,
                    ShowLabel = false,
                    MarkerWidth = 10,
                    MarkerHeight = 10,
                    MarkerColor = Color.FromHex("#FFFEBE17"),
                
                },
                ListenPropertyChange = true,
                ItemsSource = dataModel.DateTimeData,
                XBindingPath = "Date",
                YBindingPath = "Value",
            });

            ChartSelectionBehaviorExt selectionBehavior = new ChartSelectionBehaviorExt(chart, dataModel.DateTimeData);
            chart.ChartBehaviors.Add(selectionBehavior);
            
            if(Device.OS != TargetPlatform.Windows && Device.OS != TargetPlatform.WinPhone)
            {
                ChartTrackballBehaviorExt trackball = new ChartTrackballBehaviorExt();
                trackball.ShowLine = false;
                chart.ChartBehaviors.Add(trackball);
            }
           

            layout.Children.Add(chart);
            Content = layout;
        }
    }

    public class ChartTrackballBehaviorExt : ChartTrackballBehavior
    {
        protected override void OnTouchMove(float x, float y)
        {
            base.OnTouchMove(x, y);
            Show(x, y);
        }

        protected override void OnTouchUp(float x, float y)
        {
            base.OnTouchUp(x, y);
            Hide();
        }
    }

    public class ChartSelectionBehaviorExt : ChartSelectionBehavior
    {
        CustomChart chart;
        ObservableCollection<Model> datas;
        int index = -1;

        public ChartSelectionBehaviorExt(CustomChart chart, ObservableCollection<Model> data)
        {
            this.chart = chart;
            this.datas = data;
        }

        protected override void OnTouchDown(float x, float y)
        {
            base.OnTouchDown(x, y);

            if (chart.Series.Count > 0)
            {
                index = chart.Series[0].GetDataPointIndex(x, y);
            }

        }

        protected override void OnTouchMove(float x, float y)
        {
            base.OnTouchMove(x, y);

            if (chart.Series.Count <= 0 || index < 0)
                return;

            double XValue, YValue;

            if (datas.Count > index && !(index < 0))
            {
                XValue = chart.PointToValue(chart.PrimaryAxis, new Point(x, y));
                YValue = chart.PointToValue(chart.SecondaryAxis, new Point(x, y));

                datas[index].Date = XValue;
                datas[index].Value = YValue;
            }
        }
    }
}

